package apis

import (
	"duoduo/apis/bizhi/models"
	"duoduo/models/bizhi"
	"duoduo/models/mysqlBz"
	"duoduo/tools"
	"duoduo/tools/app"
	"fmt"
	"github.com/gin-gonic/gin"
)

//插入收藏
func InsertCollection(c *gin.Context) {
	var inData models.InsertCollectionRequest
	var sqlData bizhi.Collection
	var bizhi mysqlBz.BiZhi

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	fmt.Println(inData)
	bizhi.ID = inData.BiZhiId
	res, err := bizhi.BiZhiDes()
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	sqlData.OpenID = inData.OpenId
	sqlData.Url = res.Url
	sqlData.CreateTime = tools.GetCurrntTimeStr()
	sqlData.BizhiID = inData.BiZhiId
	err = sqlData.Insert()
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	app.OK(c, nil, "成功")
}

//删除收藏
func DelCollection(c *gin.Context) {
	var inData models.DelCollectionRequest
	var sqlData bizhi.Collection

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	sqlData.BizhiID = inData.BiZhiId
	sqlData.OpenID = inData.OpenId
	err = sqlData.Del()
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	app.OK(c, nil, "成功")
}

//收藏列表
func ListCollection(c *gin.Context) {
	var inData models.ListCollectionRequest
	var sqlData bizhi.Collection
	var outData []ListCollectionResponse
	var list []bizhi.CollectionBiZhi
	var count int

	var pageSize = 10
	var pageIndex = 1

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	if inData.PageSize != 0 {
		pageSize = inData.PageSize
	}
	if inData.PageIndex != 0 {
		pageIndex = inData.PageIndex
	}

	sqlData.OpenID = inData.OpenId
	if inData.Type == "1" {
		list, count, err = sqlData.GetOpenIdList(pageSize, pageIndex)
		if err != nil {
			app.Error(c, 500, err, err.Error())
			return
		}
	} else if inData.Type == "2" {
		list, count, err = sqlData.GetOpenIdDownList(pageSize, pageIndex)
		if err != nil {
			app.Error(c, 500, err, err.Error())
			return
		}
	} else {
		app.Error(c, 500, nil, "类型错误")
		return
	}

	for i := 0; i < len(list); i++ {
		data := ListCollectionResponse{}
		data.CollectionBiZhi = list[i]
		data.Cover = list[i].Url
		data.Cover1 = list[i].Url + "?imageView/1/w/350/h/467"
		data.CoverHeight = "467"
		data.CoverWidth = "350"
		data.Loaded = false
		outData = append(outData, data)

	}

	app.PageOK(c, outData, count, pageIndex, pageSize, app.Success)
}

//随机获取图片请求参数
type ListCollectionResponse struct {
	bizhi.CollectionBiZhi
	Cover1      string `json:"Cover1"`
	Cover       string `json:"Cover"`
	CoverHeight string `json:"CoverHeight"`
	CoverWidth  string `json:"CoverWidth"`
	Loaded      bool   `json:"loaded"`
}
