package apis

import (
	"duoduo/models/bizhi"
	"duoduo/models/mysqlBz"
	"duoduo/tools"
	"duoduo/tools/app"
	"fmt"
	"github.com/gin-gonic/gin"
)

func RondPicture(c *gin.Context) {
	outData := []bizhi.RoundPictureResponse{}
	biZhi := mysqlBz.BiZhi{}

	list, err := biZhi.GetRoundBiZhi()
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}

	for i := 0; i < len(list); i++ {
		data := bizhi.RoundPictureResponse{}
		data.BiZhi = list[i]
		data.Cover = list[i].Url
		data.Cover1 = list[i].Url + "?imageView/1/w/350/h/467"
		data.CoverHeight = "467"
		data.CoverWidth = "350"
		data.Loaded = false
		outData = append(outData, data)

	}
	app.OK(c, outData, app.Success)
}

func PictureLabel(c *gin.Context) {

	inData := bizhi.PictureLabelRequest{}
	sqlData := mysqlBz.BiZhi{}

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	outData, err := sqlData.GetBiZhiLabel(inData.Label)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	outData.Url = outData.Url + "?imageView/1/w/350/h/467"
	app.OK(c, outData, app.Success)

}

func PictureLabelUpdate(c *gin.Context) {
	inData := bizhi.PictureLabelUpdateRequest{}
	sqlData := mysqlBz.BiZhi{}

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	sqlData.ID = inData.Id
	err = sqlData.BiZhiLabelUpdate(inData.Label)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	app.OK(c, nil, app.Success)
}

func PictureGroup(c *gin.Context) {
	inData := bizhi.PictureGroupRequest{}
	sqlData := mysqlBz.BiZhi{}
	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	sqlData.Label = inData.Label
	sqlData.ID = inData.Id
	data, err := sqlData.BiZhiGroup(sqlData.Label, inData.OpenId)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	fmt.Println("%+v", data)
	app.OK(c, data, app.Success)

}

func Search(c *gin.Context) {
	inData := bizhi.SearchRequest{}
	sqlData := mysqlBz.BiZhi{}
	outData := []bizhi.RoundPictureResponse{}
	search := bizhi.Search{}
	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	var pageSize = 10
	var pageIndex = 1

	if inData.PageSize != 0 {
		pageSize = inData.PageSize
	}
	if inData.PageIndex != 0 {
		pageIndex = inData.PageIndex
	}

	search.CreateTime = tools.GetCurrntTimeStr()
	search.Label = inData.Label
	search.Insert()

	sqlData.Label = inData.Label
	list, count, err := sqlData.GetLabelList(pageSize, pageIndex)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	for i := 0; i < len(list); i++ {
		data := bizhi.RoundPictureResponse{}
		data.BiZhi = list[i]
		data.Cover = list[i].Url
		data.Cover1 = list[i].Url + "?imageView/1/w/350/h/467"
		data.CoverHeight = "467"
		data.CoverWidth = "350"
		data.Loaded = false
		outData = append(outData, data)

	}
	app.PageOK(c, outData, count, pageIndex, pageSize, "成功")

}
