package apis

import (
	"duoduo/apis/bizhi/models"
	"duoduo/apis/pdd"
	"duoduo/models/bizhi"
	"duoduo/tools"
	"duoduo/tools/app"
	"fmt"
	"github.com/gin-gonic/gin"
)

//获取用户openid，没有，注册用户
func OpenIdSet(c *gin.Context) {
	var inData models.OpenIdSetRequest
	var outData models.OpenIdSetResponse
	var sqlData bizhi.User
	var sql1 bizhi.User

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	url := fmt.Sprintf("https://api.weixin.qq.com/sns/jscode2session?appid=wx170728845ab9636a&secret=74fb30153a86222669ccab64a43636aa&js_code=%s&grant_type=authorization_code", inData.Code)

	val, err := pdd.DuoDuoGet(url)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}

	err = tools.JsonUnmarshal(val, &outData)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	if outData.Errcode != 0 {
		app.Error(c, outData.Errcode, err, outData.Errmsg)
		return
	}
	//查询数据
	sqlData.OpenID = outData.OpenId
	num := sqlData.GetNum()
	if num == 0 {
		if inData.OpenId != "" { //有上级更新上级加分日志
			sql1.OpenID = inData.OpenId
			//创建用户
			sqlData.CreateTime = tools.GetCurrntTimeStr()
			sqlData.UpdateTime = tools.GetCurrntTimeStr()
			sqlData.OpenID1 = inData.OpenId
			sqlData.Score = 3
			sqlData.Create()
		} else { //无上级用户
			//创建用户
			sqlData.CreateTime = tools.GetCurrntTimeStr()
			sqlData.UpdateTime = tools.GetCurrntTimeStr()
			sqlData.Score = 3
			sqlData.Create()
		}

	}

	app.OK(c, outData, app.Success)

}

//获取用户积分
func GetUserScore(c *gin.Context) {
	var inData models.GetUserScoreRequest
	var sqlData bizhi.User

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	sqlData.OpenID = inData.OpenId
	data, err := sqlData.GetScore()
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	app.OK(c, data, "成功")
}

//用户消费积分
func SubUserScore(c *gin.Context) {
	var inData models.SubUserScoreRequest
	var sqlData bizhi.User
	var score bizhi.ScoreLog

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	sqlData.OpenID = inData.OpenId
	score.OpenID = inData.OpenId
	score.Type = inData.Type
	if inData.Type == 2 { //签到领积分校验日期
		if !score.CheckScoreLog(inData.Num) {
			app.Error(c, 501, nil, "今日领取次数已满")
			return
		}
	} else if inData.Type == 3 {
		if !score.CheckScoreLog(inData.Num) {
			app.Error(c, 501, nil, "今日领取次数已满")
			return
		}
	}
	err = sqlData.SubScore(inData)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	app.OK(c, nil, "")

}

//下级用户列表
func GetUserList(c *gin.Context) {
	var inData models.GetUserListRequest

	var user bizhi.User

	var pageSize = 10
	var pageIndex = 1

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}

	if inData.PageSize != 0 {
		pageSize = inData.PageSize
	}
	if inData.PageIndex != 0 {
		pageIndex = inData.PageIndex
	}

	user.OpenID1 = inData.OpenIdOne
	userVal, count, err := user.GetOpenIdList(pageSize, pageIndex)
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}
	for i := 0; i < len(userVal); i++ {
		///pages/image/my_fill1.png
		if userVal[i].AvatarUrl == "" {
			userVal[i].AvatarUrl = "/pages/image/my_fill1.png"
		}
		if userVal[i].NickName == "" {
			userVal[i].NickName = "用户暂未授权昵称获取"
		}
	}

	app.PageOK(c, userVal, count, pageIndex, pageSize, app.Success)
}

func UpdateUser(c *gin.Context) {
	var inData models.UpdateUserScoreRequest
	var user bizhi.User

	err := c.ShouldBindJSON(&inData)
	if err != nil {
		app.Error(c, 400, err, err.Error())
		return
	}
	user.NickName = inData.NickName
	user.AvatarUrl = inData.AvatarUrl
	user.OpenID = inData.OpenId

	err = user.UpdateUserName()
	if err != nil {
		app.Error(c, 500, err, err.Error())
		return
	}

	app.OK(c, nil, "成功")

}
